@@ -737,11 +737,11 @@ mergeInto(LibraryManager.library, {
       try {
         if (event === 'error') {
           var sp = stackSave();
-          var msg = allocate(intArrayFromString(data[2]), 'i8', ALLOC_STACK);
-          {{{ makeDynCall('viiii') }}}(callback, data[0], data[1], msg, userData);
+          var msg = allocate(intArrayFromString(data[2]), ALLOC_STACK);
+          {{{ makeDynCall('viiii', 'callback') }}}(data[0], data[1], msg, userData);
           stackRestore(sp);
         } else {
-          {{{ makeDynCall('vii') }}}(callback, data, userData);
+          {{{ makeDynCall('vii', 'callback') }}}(data, userData);
         }
       } catch (e) {
         if (e instanceof ExitStatus) {
