@@ -23,16 +23,6 @@ WebAssembly = {
 #else
     this.buffer = new ArrayBuffer(opts['initial'] * {{{ WASM_PAGE_SIZE }}});
 #endif
-    this.grow = function(amount) {
-#if ASSERTIONS
-      var oldBuffer = this.buffer;
-#endif
-      var ret = __growWasmMemory(amount);
-#if ASSERTIONS
-      assert(this.buffer !== oldBuffer); // the call should have updated us
-#endif
-      return ret;
-    };
   },
 
 #if RELOCATABLE
