@@ -166,6 +166,11 @@ def get_wasm_libc_rt_files():
   return math_files + other_files + iprintf_files
 
 
+def in_temp(*args):
+  """Gets the path of a file in our temporary directory."""
+  return os.path.join(shared.get_emscripten_temp_dir(), *args)
+
+
 class Library(object):
   """
   `Library` is the base class of all system libraries.
@@ -301,10 +306,6 @@ class Library(object):
     elif os.path.isfile(default_symbols_file):
       self.symbols = read_symbols(default_symbols_file)
 
-  def in_temp(cls, *args):
-    """Gets the path of a file in our temporary directory."""
-    return os.path.join(shared.get_emscripten_temp_dir(), *args)
-
   def can_use(self):
     """
     Whether this library can be used in the current environment.
@@ -362,7 +363,7 @@ class Library(object):
     objects = []
     cflags = self.get_cflags()
     for src in self.get_files():
-      o = self.in_temp(shared.unsuffixed_basename(src) + '.o')
+      o = in_temp(shared.unsuffixed_basename(src) + '.o')
       ext = shared.suffix(src)
       if ext in ('.s', '.c'):
         cmd = [shared.EMCC]
@@ -377,7 +378,7 @@ class Library(object):
 
   def build(self):
     """Builds the library and returns the path to the file."""
-    out_filename = self.in_temp(self.get_filename())
+    out_filename = in_temp(self.get_filename())
     create_lib(out_filename, self.build_objects())
     return out_filename
 
@@ -634,7 +635,7 @@ class AsanInstrumentedLibrary(Library):
     return super(AsanInstrumentedLibrary, cls).get_default_variation(is_asan=shared.Settings.USE_ASAN, **kwargs)
 
 
-class libcompiler_rt(Library):
+class libcompiler_rt(MTLibrary):
   name = 'libcompiler_rt'
   # compiler_rt files can't currently be part of LTO although we are hoping to remove this
   # restriction soon: https://reviews.llvm.org/D71738
@@ -643,9 +644,9 @@ class libcompiler_rt(Library):
   cflags = ['-O2', '-fno-builtin']
   src_dir = ['system', 'lib', 'compiler-rt', 'lib', 'builtins']
   src_files = glob_in_path(src_dir, '*.c')
-  src_files.append(shared.path_from_root('system', 'lib', 'compiler-rt', 'extras.c'))
   src_files.append(shared.path_from_root('system', 'lib', 'compiler-rt', 'stack_ops.s'))
   src_files.append(shared.path_from_root('system', 'lib', 'compiler-rt', 'emscripten_setjmp.c'))
+  src_files.append(shared.path_from_root('system', 'lib', 'compiler-rt', 'emscripten_exception_builtins.c'))
 
 
 class libc(AsanInstrumentedLibrary, MuslInternalLibrary, MTLibrary):
@@ -1375,7 +1376,7 @@ def warn_on_unexported_main(symbolses):
         return
 
 
-def calculate(temp_files, in_temp, cxx, forced, stdout_=None, stderr_=None):
+def calculate(temp_files, cxx, forced, stdout_=None, stderr_=None):
   global stdout, stderr
   stdout = stdout_
   stderr = stderr_
@@ -1576,11 +1577,6 @@ def calculate(temp_files, in_temp, cxx, forced, stdout_=None, stderr_=None):
       add_library(system_libs_map['libstandalonewasm'])
     add_library(system_libs_map['libc_rt_wasm'])
 
-    if shared.Settings.UBSAN_RUNTIME == 1:
-      add_library(system_libs_map['libubsan_minimal_rt_wasm'])
-    elif shared.Settings.UBSAN_RUNTIME == 2:
-      add_library(system_libs_map['libubsan_rt'])
-
     if shared.Settings.USE_LSAN:
       force_include.add('liblsan_rt')
       add_library(system_libs_map['liblsan_rt'])
@@ -1588,9 +1584,13 @@ def calculate(temp_files, in_temp, cxx, forced, stdout_=None, stderr_=None):
     if shared.Settings.USE_ASAN:
       force_include.add('libasan_rt')
       add_library(system_libs_map['libasan_rt'])
-      add_library(system_libs_map['libubsan_rt'])
       add_library(system_libs_map['libasan_js'])
 
+    if shared.Settings.UBSAN_RUNTIME == 1:
+      add_library(system_libs_map['libubsan_minimal_rt_wasm'])
+    elif shared.Settings.UBSAN_RUNTIME == 2:
+      add_library(system_libs_map['libubsan_rt'])
+
     if shared.Settings.USE_LSAN or shared.Settings.USE_ASAN:
       add_library(system_libs_map['liblsan_common_rt'])
 
