@@ -209,15 +209,15 @@ var ensureCache = {
     return ret;
   },
   copy: function(array, view, offset) {
-    var offsetShifted = offset;
+    offset >>>= 0;
     var bytes = view.BYTES_PER_ELEMENT;
     switch (bytes) {
-      case 2: offsetShifted >>= 1; break;
-      case 4: offsetShifted >>= 2; break;
-      case 8: offsetShifted >>= 3; break;
+      case 2: offset >>>= 1; break;
+      case 4: offset >>>= 2; break;
+      case 8: offset >>>= 3; break;
     }
     for (var i = 0; i < array.length; i++) {
-      view[offsetShifted + i] = array[i];
+      view[offset + i] = array[i];
     }
   },
 };
@@ -282,11 +282,14 @@ function ensureFloat64(value) {
 
 mid_c += ['''
 // Not using size_t for array indices as the values used by the javascript code are signed.
+
+EM_JS(void, array_bounds_check_error, (size_t idx, size_t size), {
+  throw 'Array index ' + idx + ' out of bounds: [0,' + size + ')';
+});
+
 void array_bounds_check(const int array_size, const int array_idx) {
   if (array_idx < 0 || array_idx >= array_size) {
-    EM_ASM({
-      throw 'Array index ' + $0 + ' out of bounds: [0,' + $1 + ')';
-    }, array_idx, array_size);
+    array_bounds_check_error(array_idx, array_size);
   }
 }
 ''']
